Description Usage Value Examples
Returns a tidy data frame of LP's 5 completed, published albums with
three columns: album which contains the titles of the albums as a
factor in order of publication, song which contains the titles of the
songs as factor in order of playing considering repetition, and
lyrics, which contains the lyrics of the songs.
1 | lp_songs()
|
A data frame with three columns: album, song and
lyrics
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.